pub struct AccessRule {
pub cidr: CidrRange,
pub action: AccessAction,
pub comment: Option<String>,
}Expand description
A single access control rule.
Fields
cidr: CidrRangeCIDR range to match
action: AccessActionAction to take on match
comment: Option<String>Optional comment/description
Implementations
Sourceimpl AccessRule
impl AccessRule
Sourcepub fn allow(cidr: &str) -> Result<Self, AccessError>
pub fn allow(cidr: &str) -> Result<Self, AccessError>
Creates a new allow rule for the given CIDR.
Sourcepub fn deny(cidr: &str) -> Result<Self, AccessError>
pub fn deny(cidr: &str) -> Result<Self, AccessError>
Creates a new deny rule for the given CIDR.
Sourcepub fn with_comment(self, comment: &str) -> Self
pub fn with_comment(self, comment: &str) -> Self
Adds a comment to the rule.