ApiHandler

Struct ApiHandler 

pub struct ApiHandler { /* private fields */ }
API endpoint handlers.

Implementations

Source

impl ApiHandler

pub fn builder() -> ApiHandlerBuilder

Creates a new API handler builder.

pub fn access_lists(&self) -> Arc<RwLock<AccessListManager>>

pub fn dlp_scanner(&self) -> Option<Arc<DlpScanner>>

Returns the DLP scanner (if configured).

pub fn signal_dispatcher(&self) -> Arc<SignalDispatcher>

Signal dispatcher facade (labs-pdb2)

pub async fn report_signal(&self, signal: ThreatSignal) -> Result<(), String>

Report a threat signal to Signal Horizon (Phase 6).

pub fn is_horizon_blocked( &self, ip: Option<&str>, fingerprint: Option<&str>, ) -> bool

Check if an IP or fingerprint is blocked by Signal Horizon blocklist.

pub async fn sync_horizon_blocklist(&self) -> Result<(), String>

Force a blocklist sync with Signal Horizon.

pub async fn dispatch_horizon_signal( &self, signal: ThreatSignal, ) -> Result<(), String>

Dispatch a signal to Signal Horizon without exposing the client.

pub fn handle_health(&self) -> ApiResponse<HealthResponse>

Handles GET /health request.

pub fn handle_metrics(&self) -> String

Handles GET /metrics request. Returns Prometheus exposition format.

pub fn handle_reload(&self) -> ApiResponse<ReloadResultResponse>

Handles POST /reload request.

pub fn handle_list_sites(&self) -> ApiResponse<SiteListResponse>

Handles GET /sites request.

pub fn handle_stats(&self) -> ApiResponse<StatsResponse>

Handles GET /stats request.

pub fn handle_waf_stats(&self) -> ApiResponse<WafStatsResponse>

Handles GET /waf/stats request.

pub fn handle_get_profiles(&self) -> ApiResponse<Vec<EndpointProfile>>

Handles GET /debug/profiles request. Note: This requires the profiles_getter callback to be set; returns empty vec if not available. In the full binary context, profiles are retrieved via DetectionEngine which uses thread-local storage.

pub fn handle_reset_profiles(&self)

Handles POST /api/profiles/reset request. Clears all learned endpoint behavioral baselines.

pub fn handle_reset_schemas(&self)

Handles POST /api/schemas/reset request. Clears all learned API schemas from the schema learner.

pub fn handle_create_site( &self, request: CreateSiteRequest, ) -> ApiResponse<MutationResult>

Handles POST /sites request - creates a new site.

pub fn handle_get_site(&self, hostname: &str) -> ApiResponse<SiteDetailResponse>

Handles GET /sites/:hostname request - gets site details.

pub fn handle_update_site( &self, hostname: &str, request: UpdateSiteRequest, ) -> ApiResponse<MutationResult>

Handles PUT /sites/:hostname request - updates site configuration.

pub fn handle_delete_site(&self, hostname: &str) -> ApiResponse<MutationResult>

Handles DELETE /sites/:hostname request - deletes a site.

pub fn handle_update_site_waf( &self, hostname: &str, request: SiteWafRequest, ) -> ApiResponse<MutationResult>

Handles PUT /sites/:hostname/waf request - updates WAF configuration.

pub fn handle_update_site_rate_limit( &self, hostname: &str, request: RateLimitRequest, ) -> ApiResponse<MutationResult>

Handles PUT /sites/:hostname/rate-limit request - updates rate limit configuration.

pub fn handle_update_site_access_list( &self, hostname: &str, request: AccessListRequest, ) -> ApiResponse<MutationResult>

Handles PUT /sites/:hostname/access-list request - updates access list.

pub fn handle_get_config(&self) -> ApiResponse<ConfigFile>

Handles GET /config request - retrieves full configuration.

pub fn handle_update_config( &self, config: ConfigFile, ) -> ApiResponse<MutationResult>

Handles POST /config request - updates full configuration.

pub fn validate_auth(&self, token: Option<&str>) -> bool

Validates the API authentication token using constant-time comparison.

Uses subtle::ConstantTimeEq to prevent timing attacks that could allow attackers to guess valid tokens character-by-character.

pub fn metrics(&self) -> Arc<MetricsRegistry>

Returns the metrics registry for recording.

pub fn health(&self) -> Arc<HealthChecker>

Returns the health checker.

pub fn entity_manager(&self) -> Option<Arc<EntityManager>>

Returns the entity manager (if configured).

pub fn block_log(&self) -> Option<Arc<BlockLog>>

Returns the block log (if configured).

pub fn config_manager(&self) -> Option<&Arc<ConfigManager>>

Returns the config manager (if configured).

pub fn campaign_manager(&self) -> Option<&Arc<CampaignManager>>

Returns the campaign manager (if configured).

pub fn actor_manager(&self) -> Option<Arc<ActorManager>>

Returns the actor manager (if configured).

pub fn session_manager(&self) -> Option<Arc<SessionManager>>

Returns the session manager (if configured).

pub fn signal_manager(&self) -> Option<Arc<SignalManager>>

Returns the signal manager (if configured).

pub fn synapse_engine(&self) -> Option<Arc<RwLock<Synapse>>>

Returns the synapse engine (if configured).

pub fn evaluate_request( &self, method: &str, uri: &str, headers: &[(String, String)], body: Option<&[u8]>, client_ip: &str, ) -> Option<EvaluateResult>

Evaluates a request against the WAF rules (dry-run mode). Returns the detection result without actually blocking.

pub fn evaluate_request_trace( &self, method: &str, uri: &str, headers: &[(String, String)], body: Option<&[u8]>, client_ip: &str, trace: &mut dyn TraceSink, ) -> Option<EvaluateResult>

Evaluates a request against the WAF rules and streams trace events.

pub fn handle_list_actors(&self, limit: usize) -> Vec<ActorState>

Handles GET /_sensor/actors request - returns actors (most recently seen first).

pub fn handle_actor_stats(&self) -> Option<ActorStatsSnapshot>

Handles GET /_sensor/actors/stats request - returns actor statistics.

pub fn handle_list_sessions(&self, limit: usize) -> Vec<SessionState>

Handles GET /_sensor/sessions request - returns active sessions.

pub fn handle_session_stats(&self) -> Option<SessionStatsSnapshot>

Handles GET /_sensor/sessions/stats request - returns session statistics.

pub fn handle_list_entities(&self, limit: usize) -> Vec<EntitySnapshot>

Handles GET /_sensor/entities request - returns top entities by risk.

pub fn handle_list_blocks(&self, limit: usize) -> Vec<BlockEvent>

Handles GET /_sensor/blocks request - returns recent block events.

pub fn handle_payload_stats(&self) -> ApiResponse<PayloadSummaryResponse>

Handles GET /_sensor/payload/stats - returns payload profiling summary.

pub fn handle_payload_endpoints( &self, limit: usize, ) -> ApiResponse<Vec<EndpointPayloadSummary>>

Handles GET /_sensor/payload/endpoints - returns top endpoints by traffic.

pub fn handle_payload_anomalies( &self, limit: usize, ) -> ApiResponse<Vec<PayloadAnomalyResponse>>

Handles GET /_sensor/payload/anomalies - returns recent payload anomalies.

Handles GET /_sensor/trends/summary - returns trends summary.

Handles GET /_sensor/trends/anomalies - returns detected anomalies.

pub fn handle_signals( &self, options: SignalQueryOptions, ) -> ApiResponse<SignalListResponse>

Handles GET /_sensor/signals - returns recent intelligence signals.

pub fn handle_crawler_stats(&self) -> ApiResponse<CrawlerStatsResponse>

Handles GET /_sensor/crawler/stats - returns crawler detection stats.

pub fn handle_horizon_stats(&self) -> ApiResponse<HorizonStatsResponse>

Handles GET /_sensor/horizon/stats - returns Signal Horizon connection stats.

pub fn handle_horizon_blocklist( &self, limit: usize, ) -> ApiResponse<Vec<BlocklistEntryResponse>>

Handles GET /_sensor/horizon/blocklist - returns blocklist entries.