pub struct ShadowMirrorClient { /* private fields */ }Expand description
Async HTTP client for delivering shadow mirror payloads to honeypots.
Uses connection pooling and configurable timeouts for efficient delivery.
Implementations
Sourceimpl ShadowMirrorClient
impl ShadowMirrorClient
Sourcepub fn new(
hmac_secret: Option<String>,
timeout: Duration,
) -> Result<Self, ShadowMirrorError>
pub fn new( hmac_secret: Option<String>, timeout: Duration, ) -> Result<Self, ShadowMirrorError>
Sourcepub async fn send_to_honeypot(
&self,
urls: &[String],
payload: MirrorPayload,
timeout: Duration,
) -> Result<(), ShadowMirrorError>
pub async fn send_to_honeypot( &self, urls: &[String], payload: MirrorPayload, timeout: Duration, ) -> Result<(), ShadowMirrorError>
Sends a payload to one of the honeypot URLs.
Uses round-robin URL selection based on request ID for load distribution.
Sourcepub fn stats(&self) -> ShadowClientStats
pub fn stats(&self) -> ShadowClientStats
Returns statistics about the client.
Sourcepub fn reset_stats(&self)
pub fn reset_stats(&self)
Resets statistics.